IDORs are caused by missing access controls. If the object is accessible to authenticated users only, the endpoint
must implements check to verify the user making the request has the permissions to access the object.

